@@ -1,7 +1,6 @@
-
-
+#!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.6.0-3
+# Application Name - Health Check V0.6.0-4
 #Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -27,9 +26,9 @@
 print "** Start Imports **"
 from PyQt4 import QtCore, QtGui
 import sys
+
 # To allow os.popen ('<<Terminal command>>').read() commands
 import os
-
 # To allow os.popen() to work
 import subprocess
 
@@ -45,6 +44,7 @@ import hildon
 #import pygtk
 
 #for phone orientation call
+import dbus
 import dbus.glib
 
 from threading import Thread
@@ -239,7 +239,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_5)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.6.0-3 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
+        self.textBrowser.setText (" Health Check V 0.6.0-4 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -299,7 +299,7 @@ class Ui_MainWindow(object):
         print "** Empty List Added**"
         
 # Funtion - update GPS - Using lib-location
-    def updateGPS(self):
+    def updateGPS(self, MainWindow):
         print "** Updating GPS Info**"
         global var_g_GPS
         global var_g_ALT
@@ -516,9 +516,9 @@ class Ui_MainWindow(object):
 
 # Funtion - update Accelerator information
     def updateAccel(self):
-        print " ** Importing dbus.glib **"
-        import dbus.glib
-        print " ** Glib done**"
+        #print " ** Importing dbus.glib **"
+        #import dbus.glib
+        #print " ** Glib done**"
 
         # set f to = the accellerometer co-ordinates
         # the co-ords need to be pulled out and split for easy reading
@@ -544,9 +544,9 @@ class Ui_MainWindow(object):
             #print "  %s - %s" % (addr, name)
 
     def vibrateon(self):
-        print " ** importing dbus.glib**"
-        import dbus.glib
-        print " ** got dbus.glib**"
+        #print " ** importing dbus.glib**"
+        #import dbus.glib
+        #print " ** got dbus.glib**"
 
         print " ** testing vibrations**"
         bus = dbus.SessionBus()
@@ -595,9 +595,9 @@ class Ui_MainWindow(object):
         print " ** finished vibrations**"
         
     def updateLED(self):
-        print " ** importing dbus.glib**"
-        import dbus.glib
-        print " ** Starting LED Patterns**"
+        #print " ** importing dbus.glib**"
+        #import dbus.glib
+        #print " ** Starting LED Patterns**"
         bus = dbus.SessionBus()
         proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
         interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
@@ -694,9 +694,9 @@ class Ui_MainWindow(object):
         self.pushButton_com.setEnabled(False)
         self.pushButton_a2.setEnabled(False)
         self.pushButton_com.setText("...")
-        self.updateGPS()
+        self.updateGPS(MainWindow)
         self.pushButton_com.setText(".....")
-        self.Cellular()
+        self.Cellular(MainWindow)
         self.pushButton_com.setText("......")
         self.updatenetname()
         self.pushButton_com.setText("Update Tab")
@@ -727,7 +727,7 @@ class Ui_MainWindow(object):
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.6.0-3", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.6.0-4", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Camera", None, QtGui.QApplication.UnicodeUTF8))
@@ -736,10 +736,10 @@ class Ui_MainWindow(object):
         
 # Cell_info - Taken from netmon code. Need to figure out the author so i can give proper thanks!
 # can be found here - http://repository.maemo.org/extras-devel/pool/fremantle/free/source/n/netmon/
-    def Cellular(self):
+    def Cellular(self,MainWindow):
         print " ** Starting Cellular*"
         print " ** Importing dbus**"
-	import dbus
+	#import dbus
 	
 	regstatus = gn_cellinfo.RegStatus()
 	signalstrength = gn_cellinfo.SignalStrength()
@@ -860,7 +860,10 @@ if __name__ == "__main__":
     import sys
     print " ** Starting Main **"
     print " ** app = QtGui App** - Running app = QtGui.QApplication(sys.argv) **"
+
     app = QtGui.QApplication(sys.argv)
+
+    #app = QtGui.QApplication(sys.argv)
     print " ** Setting Main Window**"
     MainWindow = QtGui.QMainWindow()
     print " ** Declare the UI**"
